@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from django.conf import settings
+from django.conf import settings as site_settings
 
 
 DEFAULT_SETTINGS = {
@@ -8,6 +8,6 @@ DEFAULT_SETTINGS = {
 }
 
 USER_SETTINGS = DEFAULT_SETTINGS.copy()
-USER_SETTINGS.update(getattr(settings, '{{app_name}}_SETTINGS'))
+USER_SETTINGS.update(getattr(site_settings, '{{app_name}}_SETTINGS', {}))
 
 globals().update(USER_SETTINGS)
